@@ -12,7 +12,7 @@ Python libraries, though it does make heavy use of external packaging commands.
 Visit <https://github.com/datalad/datalad-installer> for more information.
 """
 
-__version__ = "0.11.1"
+__version__ = "0.11.2"
 __author__ = "The DataLad Team and Contributors"
 __author_email__ = "team@datalad.org"
 __license__ = "MIT"
@@ -182,7 +182,7 @@ class Option:
 
     def __eq__(self, other: Any) -> bool:
         if type(self) is type(other):
-            return vars(self) == vars(other)
+            return bool(vars(self) == vars(other))
         else:
             return NotImplemented
 
@@ -344,7 +344,7 @@ class OptionParser:
         except GetoptError as e:
             raise UsageError(str(e), self.component)
         kwargs: Dict[str, Any] = {}
-        for (o, a) in optlist:
+        for o, a in optlist:
             option = self.options[o]
             try:
                 ret = option.process(kwargs, a)
@@ -2545,6 +2545,13 @@ def download_file(
             with urlopen(req) as r:
                 with open(path, "wb") as fp:
                     shutil.copyfileobj(r, fp)
+                if "content-length" in r.headers:
+                    size = int(r.headers["Content-Length"])
+                    fsize = os.path.getsize(path)
+                    if fsize < size:
+                        raise URLError(
+                            f"only {fsize} out of {size} bytes were received"
+                        )
             return
         except URLError as e:
             if isinstance(e, HTTPError) and e.code not in (500, 502, 503, 504):
